@@ -10,13 +10,12 @@
 
 #include "unitcategory.h"
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 #include <QMap>
 
 namespace KUnitConversion
 {
-
 class UnitCategoryPrivate : public QSharedData
 {
 public:
@@ -30,6 +29,35 @@ public:
 
     virtual Value convert(const Value &value, const Unit &toUnit);
 
+    virtual bool hasOnlineConversionTable() const
+    {
+        return false;
+    }
+
+    virtual void syncConversionTable(std::chrono::seconds updateSkipPeriod)
+    {
+        Q_UNUSED(updateSkipPeriod)
+        return;
+    }
+
+    void addDefaultUnit(const Unit &unit);
+    void addCommonUnit(const Unit &unit);
+    void addUnit(const Unit &unit);
+
+    static inline UnitCategoryPrivate* get(const UnitCategory &category)
+    {
+        return category.d.data();
+    }
+
+    static inline UnitCategory makeCategory(CategoryId id, const QString &name, const QString &description)
+    {
+        return UnitCategory(new UnitCategoryPrivate(id, name, description));
+    }
+    static inline UnitCategory makeCategory(UnitCategoryPrivate *dd)
+    {
+        return UnitCategory(dd);
+    }
+
     CategoryId m_id;
     QString m_name;
     QString m_description;
@@ -41,20 +69,6 @@ public:
     QList<Unit> m_mostCommonUnits;
 };
 
-class CustomCategory : public UnitCategory
-{
-public:
-    CustomCategory(UnitCategoryPrivate *dd) : UnitCategory(dd)
-    {}
-
-    CustomCategory(CategoryId id, const QString &name, const QString &description)
-        : UnitCategory(new UnitCategoryPrivate(id, name, description))
-    {}
-
-    virtual ~CustomCategory()
-    {}
-};
-
 } // KUnitConversion namespace
 
 #endif // KUNITCONVERSION_UNITCATEGORY_P_H
